summaryrefslogtreecommitdiff
path: root/gtk2_ardour/editor.cc
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/editor.cc')
-rw-r--r--gtk2_ardour/editor.cc6
1 files changed, 4 insertions, 2 deletions
diff --git a/gtk2_ardour/editor.cc b/gtk2_ardour/editor.cc
index 48a08fae98..7dbb886f9e 100644
--- a/gtk2_ardour/editor.cc
+++ b/gtk2_ardour/editor.cc
@@ -5925,9 +5925,11 @@ Editor::super_rapid_screen_update ()
snapped_cursor->set_position (ms.sample);
snapped_cursor->show ();
}
- } else if (mouse_sample (where.sample, ignored)) { // cursor is in the editing canvas. show it.
+ } else if (_edit_point == EditAtMouse && mouse_sample (where.sample, ignored)) {
+ /* cursor is in the editing canvas. show it. */
snapped_cursor->show ();
- } else { // mouse is out of the editing canvas. hide the snapped_cursor
+ } else {
+ /* mouse is out of the editing canvas, or edit-point isn't mouse. Hide the snapped_cursor */
snapped_cursor->hide ();
}